##############################################################################################################
## MOD Title: SmartFeed
## MOD Author: MarkDHamill < mhamill@computer.org > (Mark D. Hamill) http://www.potomactavern.org
## MOD Description: Provides RSS 0.91, RSS 1.0, RSS 2.0, Atom 1.0 customized newsfeeds. Users select forums
##           they want, including protected forums if they can access them.
## MOD Version: 1.0.2 (Production Version), 2006-03-01
##
## Installation Level: Easy
## Installation Time: 5 Minutes or less
##
## Files To Edit:	lang_faq.php
## Included Files:	feedcreator.class.php,
##			smartfeed.php,
##			smartfeed_url.php,
##			smartfeed_url_body.tpl
##			lang_smartfeed.php
##          smartfeed_constants.php
##          xml.gif
## License: http://opensource.org/licenses/gpl-license.php GNU General Public License v2 
##############################################################
## For security purposes, please check: http://www.phpbb.com/mods/
## for the latest version of this MOD. Although MODs are checked
## before being allowed in the MODs Database there is no guarantee
## that there are no security problems within the MOD. No support
## will be given for MODs not found within the MODs Database which
## can be found at http://www.phpbb.com/mods/
##############################################################
## Author Notes:
##
## phpBB forums may contain restricted forums that should not normally be exposed as a newsfeed. Smartfeed
## is a phpBB modification, derived from my phpBB Email Digest modification, that allows users to get a newsfeed
## for selected forums, including restricted forums if they have the privilege. This is done by using an 
## interface program called smartfeed_url.php which creates a URL that authenticates the user with phpBB.
## Smartfeed is smart enough to keep users out of forums for which they do not have access, even if they hack
## parameters on the URL field. Authentication is reasonably sophisticated. Those who are not registered can 
## access in the newsfeed only those forums that can be read by the public.
##
## The URL generated by smartfeed_url.php is then copied and pasted by the user into their newsreader. The user
## needs to be smart enough to specify a newsfeed that their newsreader can interpret. RSS 0.91, RSS 1.0, RSS 2.0
## and ATOM 1.0 newsfeeds are supported.
##
## Rather than reinvent the wheel, this mod uses the FeedCreator PHP class originally written by Kai Blankenhorn,
## but extended by Scott Reynen and Dirk Clemen, with on the fly feed code added by Fabian Wolf and ATOM 1.0 support 
## added by Mohammad Hafiz bin Ismail. I modified a few lines of the class (see comments in the class with MDH in them).
##
## This has been tested, but not extensively, by validating reasonably complex feeds for RSS 0.91, RSS 1.0, RSS 2.0 and 
## ATOM 1.0 at http://feedvalidator.org. I have noticed that curly quotes and the like in the content may cause parser
## warnings.
##
## It has been tested on a MySQL 4.0 environment only but should be DBAL compliant.
##
## After installation:
##   - Feel free to change the values in /language/lang_english/lang_smartfeed.php. You may not like the defaults.
##   - If necessary change the DEFINE values in /includes/smartfeed_constants.php too.
##   - (Optional) Create links as appropriate to smartfeed_url.php on your site to give it visibility. The image xml.gif
##     is placed in /templates/subSilver/images for you to use or link to as necessary. It is suggested that if you use the 
##     image it should be linked to smartfeed_url.php
##   - To try it out, first run smartfeed_url.php. After pressing Generate, copy and paste the resulting complex URL into your newsreader.
##   - Run your newsreader using the copied URL and enjoy the results
##
## While this mod is free, if you want to encourage me to keep it up to date or write other similar mods, feel free to send me 
## a donation of $10 or more. My PayPal account is mhamill@computer.org.
##
## This MOD is EasyMOD Friendly! 
##
##############################################################
## MOD History:
##
##   2005-12-29 - Version 0.0.0
##      - First Alpha version for comments
##   2006-01-01 - Version 0.0.1
##      - Password is now encrypted using $dbpasswd, drastically reducing the likelihood the phpBB password can be hacked
##		- Incorporated Conditional Get logic found at http://simon.incutio.com/archive/2003/04/23/conditionalGet. Returns HTTP 304
##        if there are no new posts, saving a lot of bandwidth!
##   2006-01-02 - Version 0.0.2
##      - Added optional IP Authentication. If selected the URL cannot be "hijacked". For example, someone cannot use the URL at
##		  work if it was created at home. For sites with sensitive information this may be an issue.
##      - $siteURL adds a "/" to the end if needed 
##   2006-01-06 - Version 0.1 (First Beta)
##      - Works with EasyMod
##      - If there is an error the error message appears in the newsfeed itself, instead of returning a HTML page
##      - Now allows access by non registered people to public forums only
##		- Administrator can set a maximum number of items to be returned in a newsfeed
##		- Sets and uses a cookie to determine when newsfeed was last requested
##   2006-01-21 - Version 0.2 
##      - Fixed bug in smartfeed_url.php. Creates $siteURL value similar to smartfeed.php
##		- User can elect to filter out their own posts, similar to Digest mod
##		- Changed feedcreator.class.php to return RSS 1.0 and RSS 2.0 to have a MIME type of text/xml. While
##		  the validator at feedcreator.org complains it has to be type application/xml if selected from browsers like
##		  Firefox it wants to download it as a file. I think this is too confusing at the moment. ATOM 1.0 MIME type also
##		  returned to type application/xml.
##		- Note: the store cookie feature that stores the last access time still needs some thought. It works fine for browser plug ins
##        like Sage, but otherwise probably won't work. Stand alone feed readers will likely ignore cookies, as will web aggregator sites
##		  like bloglines.com.
##		- If you installed version 0.1 make sure to reinstall all files!
##   2006-01-28 - Version 0.3
##		- Pretty important bug found: password was not encrypting correctly. Reinstall all files and use smartfeed_url.php to regenerate
##		  the URL to use. Make sure anyone using the Beta version to date updates the URLs. Otherwise they will get smartfeed errors.
##		- Smilies path now corrected. Most newsreaders will show smily images.
##		- smartfeed_url_body.tpl Javascript corrected so that when All Forums is unchecked the forums underneath are also unchecked. This
##		  used to work but got corrupted when I added <span> tags.
##		- smartfeed_url_body.tpl also is now WAI and Section 508 compliant, which mostly involved adding a lot of <label> tags.
##   2006-02-20 - Version 0.4 (Hopefully final Beta version!)
##      - Fixed Smilies URL problem
##      - An appropriate error message is generated if no arguments are used calling smartfeed.php
##      - Included xml.gif image. Does not need to be used but can be used to link to smartfeed_url.php.
##      - Included change to lang_faq.php to add a FAQ question about newsfeeds
##		- Added a smartfeeds_constant.php include file, to fully separate out the non-language components of lang_constants.php
##		- Tweaked feedcreator.class.php a bit in order to remove some feed validator warnings
##   2006-02-25 - Version 1.0 (Production Release, if the phpBB gods approve)
##		- Took out all MySQL specific functions and created equivalent functionality in PHP. Hopefully software is now DBAL compliant.
##		- Renamed some variables to more accurately describe their functions
##		- Moved fake email address to smartfeed_constants.php where it belongs
##   2006-02-26 - Version 1.0.1
##      - Fixed minor bug that wasn't showing the post time in the message text in smartfeed.php
##	 2006-03-01 - Version 1.0.2
##		- Changed one line of SQL in smartfeed.php which might cause a problem for those not using MySQL.
##
##############################################################
## Before Adding This MOD To Your Forum, You Should Back Up All Files Related To This MOD
############################################################## # 
#-----[ COPY ]------------------------------------------
#
copy smartfeed.php to smartfeed.php
copy smartfeed_url.php to smartfeed_url.php
copy /includes/feedcreator.class.php to /includes/feedcreator.class.php
copy /language/lang_english/lang_smartfeed.php to /language/lang_english/lang_smartfeed.php
copy /templates/subSilver/smartfeed_url_body.tpl to /templates/subSilver/smartfeed_url_body.tpl
copy /templates/subSilver/images/xml.gif to /templates/subSilver/images/xml.gif
copy /includes/smartfeed_constants.php to /includes/smartfeed_constants.php
#
#-----[ OPEN ]------------------------------------------
#
language/lang_english/lang_faq.php
#
#-----[ FIND ]------------------------------------------
#
//
// This ends the FAQ entries
//
#
#-----[ BEFORE, ADD ]------------------------------------------
#
$faq[] = array("--","Newsfeeds");
$faq[] = array("Are your forums accessible as a newsfeed using RSS and Atom protocols?","Yes. This site has installed the Smartfeed phpBB modification, which allows access to both our public and private forums. Accessing private forums requires appropriate authorizations. <a href=\"./smartfeed_url.php\">Learn more.</a>"); 

#
#-----[ SAVE/CLOSE ALL FILES ]------------------------------------------
#
#
# EoM  